<?php
/*
Plugin Name: BMI Calculator
Description: A simple plugin to add a BMI Calculator to your WordPress website.
Version: 1.0
Author: Techcript Solutions
Author URL: www.techcript.com
*/

// Add a shortcode to display the BMI calculator
function bmi_calculator_shortcode() {
    // Output the BMI calculator form
    $output = '<div id="bmi-calculator">
        <form id="bmi-form">
            <label for="bmi-weight">Weight (kg):</label>
            <input type="number" id="bmi-weight" name="weight" step="0.1" required>

            <label for="bmi-height">Height (cm):</label>
            <input type="number" id="bmi-height" name="height" step="0.1" required>

            <button type="button" id="bmi-submit">Calculate BMI</button>
        </form>
        <div id="bmi-result" style="margin-top:10px; font-weight:bold;"></div>
    </div>';

    // Include JavaScript for BMI calculation
    $output .= '<script>
        document.getElementById("bmi-submit").addEventListener("click", function() {
            const weight = parseFloat(document.getElementById("bmi-weight").value);
            const height = parseFloat(document.getElementById("bmi-height").value) / 100; // Convert cm to meters

            if (!weight || !height || height <= 0 || weight <= 0) {
                document.getElementById("bmi-result").innerText = "Please enter valid inputs.";
                return;
            }

            const bmi = (weight / (height * height)).toFixed(2);
            let category = "";

            if (bmi < 18.5) {
                category = "Underweight";
            } else if (bmi >= 18.5 && bmi < 24.9) {
                category = "Normal weight";
            } else if (bmi >= 25 && bmi < 29.9) {
                category = "Overweight";
            } else {
                category = "Obesity";
            }

            document.getElementById("bmi-result").innerText = `Your BMI is ${bmi} (${category}).`;
        });
    </script>';

    return $output;
}
add_shortcode('bmi_calculator', 'bmi_calculator_shortcode');

// Enqueue styles for the calculator
function bmi_calculator_styles() {
    echo '<style>
        #bmi-calculator {
            max-width: 400px;
            margin: 20px auto;
            padding: 20px;
            border: 1px solid #ccc;
            border-radius: 10px;
            background-color: #f9f9f9;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        #bmi-calculator label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }
        #bmi-calculator input {
            width: 100%;
            padding: 8px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
        }
        #bmi-calculator button {
            width: 100%;
            padding: 10px;
            background-color: #0073aa;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }
        #bmi-calculator button:hover {
            background-color: #005177;
        }
    </style>';
}
add_action('wp_head', 'bmi_calculator_styles');
